usage property
Generates a string displaying usage information for this command.
This includes usage for the command's arguments as well as a list of subcommands, if there are any.
Implementation
@override
String get usage => '''
Usage: init_pro create-feature <feature_name>
Generate boilerplate for:
- Data layer (repositories, models, data sources)
- Domain layer (entities, use cases, repositories)
- Presentation layer (widgets, blocs)
Example:
init_pro create-feature auth
''';