commands/add_component_command library
Classes
- AddComponentCommand
- Command to generate reusable boilerplate code for various Flutter components
Functions
-
createComponent(
String componentName) → void - Creates the specified Flutter component by calling the appropriate function