usage property
Generates a string displaying usage information for this command.
This includes usage for the command's arguments as well as a list of subcommands, if there are any.
Implementation
@override
String get usage => '''
Usage: init_pro add-component <component-name>
Generate boilerplate for:
- Adds a component to lib/core/widgets directory
Example:
init_pro add-component elevated-button
''';