usage property
Generates a string displaying usage information for this command.
This includes usage for the command's arguments as well as a list of subcommands, if there are any.
Implementation
@override
String get usage => '''
Initialize the project with:
- Clean architecture setup
- Core and helper configurations
- Predefined dependencies setup (flutter_bloc, get_it, etc.)
''';